@@ -26,9 +26,10 @@ class MeanStatTest(absltest.TestCase):
 
   def test_str(self):
     stat = metrics.MeanStat.new(2, 4)
-    self.assertEqual(
-        'MeanStat(accum=DeviceArray(2, dtype=int32), weight=DeviceArray(4, dtype=int32)) => 0.5',
-        str(stat))
+    self.assertRegex(
+        str(stat),
+        r'MeanStat\(accum=DeviceArray\(2, .*\), weight=DeviceArray\(4, .*\)\) => 0.5'
+    )
 
   def test_new(self):
     stat = metrics.MeanStat.new(jnp.array([2, 3, 1]), jnp.array([1, 0, 1]))
@@ -57,8 +58,7 @@ class SumStatTest(absltest.TestCase):
 
   def test_str(self):
     stat = metrics.SumStat.new(2)
-    self.assertEqual('SumStat(accum=DeviceArray(2, dtype=int32)) => 2',
-                     str(stat))
+    self.assertRegex(str(stat), r'SumStat\(accum=DeviceArray\(2, .*\)\) => 2')
 
   def test_result(self):
     stat = metrics.SumStat.new(2)
@@ -115,6 +115,63 @@ class MetricsTest(parameterized.TestCase):
       accuracy = metric.evaluate_example(example, prediction)
       self.assertEqual(accuracy.result(), expected_result)
 
+  @parameterized.named_parameters(
+      {
+          'testcase_name': 'correct, 0 < k < classes',
+          'kval': 3,
+          'target': 2,
+          'prediction': [0.7, 0., 0.2, -0.02, 0.6],
+          'expected_result': 1.,
+      }, {
+          'testcase_name': 'incorrect, 0 < k < classes',
+          'kval': 2,
+          'target': 0,
+          'prediction': [0., -0.2, 0.5, 0.55, 0.],
+          'expected_result': 0.,
+      }, {
+          'testcase_name': 'incorrect, k = 0',
+          'kval': 0,
+          'target': 2,
+          'prediction': [0., 0., 1., 0.],
+          'expected_result': 0.,
+      }, {
+          'testcase_name': 'incorrect, k < 0',
+          'kval': -5,
+          'target': 2,
+          'prediction': [0., 0., 1., 0.],
+          'expected_result': 0.,
+      }, {
+          'testcase_name': 'correct, k > classes',
+          'kval': 5,
+          'target': 2,
+          'prediction': [0., 0., 1., 0.],
+          'expected_result': 1.,
+      }, {
+          'testcase_name': 'correct, same prediction for multiple classes',
+          'kval': 3,
+          'target': 0,
+          'prediction': [0., .3, 1., 0.],
+          'expected_result': 1.,
+      }, {
+          'testcase_name': 'incorrect, same prediction for multiple classes',
+          'kval': 3,
+          'target': 3,
+          'prediction': [0., 0., 1., 0.],
+          'expected_result': 0.,
+      })
+  def test_top_k_accuracy(self, kval, target, prediction, expected_result):
+    example = {'y': jnp.array(target)}
+    prediction = jnp.array(prediction)
+    metric = metrics.TopKAccuracy(k=kval)
+    with self.subTest('zero'):
+      zero = metric.zero()
+      self.assertEqual(zero.accum, 0)
+      self.assertEqual(zero.weight, 0)
+    with self.subTest('evaluate_example'):
+      top_k_accuracy = metric.evaluate_example(example, prediction)
+      self.assertEqual(top_k_accuracy.accum, expected_result)
+      self.assertEqual(top_k_accuracy.weight, 1.)
+
   def test_sequence_token_cross_entropy_loss(self):
     example = {'y': jnp.array([1, 0, 1])}
     prediction = jnp.array([[1.2, 0.4], [2.3, 0.1], [0.3, 3.2]])
@@ -174,6 +231,30 @@ class MetricsTest(parameterized.TestCase):
       npt.assert_array_equal(per_position_accuracy.weight,
                              [1., 1., 1., 1., 1., 0.])
 
+  def test_sequence_token_top_k_accuracy(self):
+    example = {'y': jnp.array([1, 2, 2, 1, 3, 0])}
+    prediction = jnp.array([[0, 1, 0.5, 0], [1, 0.5, 0, 0], [0.8, 0, 0.7, 0.2],
+                            [0.5, 1, 0, 1], [0, 0.5, 0, 1], [0.5, 0, 0.9, 0.5]])
+    logits_mask = (0., 0., 0., jnp.NINF)
+    metric = metrics.SequenceTokenTopKAccuracy(k=2, logits_mask=logits_mask)
+    with self.subTest('zero'):
+      zero = metric.zero()
+      self.assertEqual(zero.accum, 0)
+      self.assertEqual(zero.weight, 0)
+    with self.subTest('evaluate_example'):
+      accuracy = metric.evaluate_example(example, prediction)
+      self.assertEqual(accuracy.accum, 3)
+      self.assertEqual(accuracy.weight, 5)
+    with self.subTest('per_position evaluate_example'):
+      per_position_metric = metrics.SequenceTokenTopKAccuracy(
+          k=2, logits_mask=logits_mask, per_position=True)
+      per_position_accuracy = per_position_metric.evaluate_example(
+          example, prediction)
+      npt.assert_array_almost_equal(per_position_accuracy.accum,
+                                    [1., 0., 1., 1., 0., 0.])
+      npt.assert_array_equal(per_position_accuracy.weight,
+                             [1., 1., 1., 1., 1., 0.])
+
   def test_sequence_token_count(self):
     example = {'y': jnp.array([1, 2, 2, 3, 4, 0, 0])}
     prediction = jnp.array([])  # Unused.
@@ -279,6 +360,37 @@ class MetricsTest(parameterized.TestCase):
     npt.assert_array_equal(stat.accum, [0., 0., 0., 0.])
     npt.assert_array_equal(stat.weight, [0., 0., 1., 0.])
 
+  @parameterized.named_parameters(
+      {
+          'testcase_name': 'correct',
+          'target': 1,
+          'prediction': [0., 1., 0.],
+          'expected_result': [[0., 0., 0.], [0., 1., 0.], [0., 0., 0.]],
+      }, {
+          'testcase_name': 'incorrect',
+          'target': 1,
+          'prediction': [1., 0., 0.],
+          'expected_result': [[0., 0., 0.], [1., 0., 0.], [0., 0., 0.]],
+      })
+  def test_confusion_matrix(self, target, prediction, expected_result):
+    example = {'y': jnp.array(target)}
+    prediction = jnp.array(prediction)
+    num_classes = len(prediction)
+    metric = metrics.ConfusionMatrix(num_classes=num_classes)
+    with self.subTest('zero'):
+      zero = metric.zero()
+      npt.assert_array_equal(zero.accum, jnp.zeros((num_classes, num_classes)))
+    with self.subTest('evaluate_example'):
+      confusion_matrix = metric.evaluate_example(example, prediction)
+      npt.assert_array_equal(confusion_matrix.result(), expected_result)
+
+  def test_confusion_matrix_invalid_input(self):
+    example = {'y': jnp.array(1)}
+    prediction = jnp.array([0., 1.])
+    metric = metrics.ConfusionMatrix(num_classes=3)
+    with self.assertRaisesRegex(ValueError, 'Make sure num_classes is equal'):
+      metric.evaluate_example(example, prediction)
+
 
 if __name__ == '__main__':
   absltest.main()
